@@ -10,6 +10,8 @@
 #include "syshdr.h"
 #include <smb/smb_fs.h>
 #include "my_defines.h"
+#include <time.h>
+#include <sys/time.h>
 
 struct timezone	sys_tz;
 
