@@ -11,6 +11,9 @@
 #include <smb/smbno.h>
 #include <smb/smb_fs.h>
 #include <syshdr.h>
+#ifdef RECODE
+#	include "recode.h"
+#endif
 
 #define SMB_VWV(packet)  ((packet) + SMB_HEADER_LEN)
 #define SMB_CMD(packet)  ((packet)[8])
@@ -89,9 +92,12 @@ smb_encode_dialect(byte *p, const byte *name, int len)
 static byte *
 smb_encode_ascii(byte *p, const byte *name, int len)
 {
-        *p ++ = 4;
-        strcpy(p, name);
-        return p + len + 1;
+	*p ++ = 4;
+	strcpy(p, name);
+#ifdef RECODE
+	recode(p, KA_RECODE);
+#endif
+	return p + len + 1;
 }
 
 static byte *
@@ -171,6 +177,22 @@ local2utc(int time)
         return time + sys_tz.tz_minuteswest*60;
 }
 
+#if 0	/* patch for correct DST handling: */
+static int
+utc2local(int time) 
+{ 
+	struct tm *t=localtime(&time); 
+	return time - (t->tm_isdst ? altzone : timezone); 
+} 
+  
+static int 
+local2utc(int time) 
+{ 
+	struct tm *t=localtime(&time); 
+	return time + (t->tm_isdst ? altzone : timezone); 
+} 
+#endif
+
 /* Convert a MS-DOS time/date pair to a UNIX date (seconds since 1 1 70). */
 
 static int
@@ -872,7 +894,7 @@ smb_proc_unlink(struct smb_server *server, const char *path, const int len)
 
  retry:
         p = smb_setup_header(server, SMBunlink, 1, 2 + len);
-        WSET(buf, smb_vwv0, 0);
+        WSET(buf, smb_vwv0, aSYSTEM | aHIDDEN);
         smb_encode_ascii(p, path, len);
 
         if ((result = smb_request_ok(server, SMBunlink, 0, 0)) < 0) {
@@ -915,6 +937,9 @@ smb_decode_dirent(char *p, struct smb_dirent *entry)
                 date_dos2unix(WVAL(p, 1), WVAL(p, 3));
         entry->size = DVAL(p, 5);
         memcpy(entry->path, p+9, 13);
+#ifdef RECODE
+		recode(entry->path,AK_RECODE);
+#endif
         DDPRINTK("smb_decode_dirent: path = %s\n", entry->path);
         return p + 22;
 }
@@ -950,6 +975,9 @@ smb_proc_readdir_short(struct smb_server *server, struct inode *dir, int fpos,
 #endif
 
         strcpy(mask, SMB_FINFO(dir)->path);
+#ifdef RECODE
+		recode(mask, KA_RECODE);
+#endif
         strcat(mask, "\\*.*");
 
         DPRINTK("SMB call  readdir %d @ %d\n", cache_size, fpos);        
@@ -1074,6 +1102,9 @@ smb_decode_long_dirent(char *p, struct smb_dirent *finfo, int level)
                         DPRINTK("received entry\n");
 						DPRINTK("resume key = %d\n", DVAL(p,0));
                         strcpy(finfo->path,p+27);
+#ifdef RECODE
+						recode(finfo->path,AK_RECODE);
+#endif
                         finfo->len  = strlen(finfo->path);
                         finfo->size = DVAL(p,16);
                         finfo->attr = BVAL(p,24);
@@ -1089,6 +1120,9 @@ smb_decode_long_dirent(char *p, struct smb_dirent *finfo, int level)
                 if (finfo)
                 {
                         strcpy(finfo->path,p+31);
+#ifdef RECODE
+						recode(finfo->path,AK_RECODE);
+#endif
                         finfo->len  = strlen(finfo->path);
                         finfo->size = DVAL(p,16);
                         finfo->attr = BVAL(p,24);
@@ -1125,6 +1159,9 @@ smb_decode_long_dirent(char *p, struct smb_dirent *finfo, int level)
                         p += 2; /* short name len? */
                         p += 24; /* short name? */        
                         strncpy(finfo->path,p,namelen);
+#ifdef RECODE
+						recode(finfo->path,AK_RECODE);
+#endif
                         finfo->len = namelen;
                 }
                 break;
@@ -1177,6 +1214,9 @@ smb_proc_readdir_long(struct smb_server *server, struct inode *dir, int fpos,
 				return -ENOMEM;
 		}
 		strcpy(mask, SMB_FINFO(dir)->path);
+#ifdef RECODE
+		recode(mask, KA_RECODE);
+#endif
 		strcat(mask, "\\*");
 
 		DPRINTK("SMB call lreaddir %d @ %d\n", cache_size, fpos);		 
@@ -1233,8 +1273,7 @@ smb_proc_readdir_long(struct smb_server *server, struct inode *dir, int fpos,
 				{
 						WSET(p,0,attribute); /* attribute */
 						WSET(p,2,max_matches); /* max count */
-						WSET(p,4,8+4+2); /* resume required + close on end +
-											continue */
+						WSET(p,4,4+2); /* resume required + close on end */
 						WSET(p,6,info_level); 
 						DSET(p,8,0);
 						p += 12;
