@@ -56,4 +56,4 @@ else
 	done
 fi
 
-exit $revtal
+exit $retval
